var group__PkgKernel23Concepts =
[
    [ "Kernel Geometric Object Concepts", "group__PkgKernel23ConceptsGeomObject.html", "group__PkgKernel23ConceptsGeomObject" ],
    [ "Kernel Function Object Concepts", "group__PkgKernel23ConceptsFunctionObjects.html", "group__PkgKernel23ConceptsFunctionObjects" ],
    [ "Kernel", "classKernel.html", [
      [ "Angle", "classKernel.html#ac4cc3c20bee8e6ac2b9b6f130e3ce892", null ],
      [ "Angle_2", "classKernel.html#ac93d0ddc1ee5a0a92d92a644cb1e850c", null ],
      [ "Angle_3", "classKernel.html#ae1a925ad8f9c401ba2f4002fa15957c0", null ],
      [ "Are_ordered_along_line_2", "classKernel.html#a91ebff75cb384648bb2c5871c7ffbbaa", null ],
      [ "Are_ordered_along_line_3", "classKernel.html#a0bed28427dd8c950df00f4bb80d67791", null ],
      [ "Are_parallel_2", "classKernel.html#a307678adbe63d9869eb12e824057bca8", null ],
      [ "Are_parallel_3", "classKernel.html#a678f2f14083963317f09ea9f751a86fb", null ],
      [ "Are_strictly_ordered_along_line_2", "classKernel.html#a948a73419a551df53ed4c79b11973af9", null ],
      [ "Are_strictly_ordered_along_line_3", "classKernel.html#ad5ee466974e3bb2a37917adcb6493dd0", null ],
      [ "Assign_2", "classKernel.html#a5bf072d587368a70c43e2c7eff799246", null ],
      [ "Assign_3", "classKernel.html#a56070b696c973a6405464ca10787964e", null ],
      [ "Boolean", "classKernel.html#aec721adb2443613061f06c8778be4758", null ],
      [ "Bounded_side", "classKernel.html#af1017c4d245ad79939333535bcadbd44", null ],
      [ "Bounded_side_2", "classKernel.html#ae8b2eb5c2fe4f55bdf095127e679d7b0", null ],
      [ "Bounded_side_3", "classKernel.html#ad11d32275700bfb2b4ae658642c749b2", null ],
      [ "Cartesian_const_iterator_2", "classKernel.html#a33eef3ded1c90e357728ec13ddd0de5b", null ],
      [ "Cartesian_const_iterator_3", "classKernel.html#acdfc207a8231923bad71797bcd0bfffa", null ],
      [ "Circle_2", "classKernel.html#ad816552df930590e5a092001dead3730", null ],
      [ "Circle_3", "classKernel.html#ae0a697c5087cd758d527834d2d9db2a6", null ],
      [ "Collinear_2", "classKernel.html#ab1d50a0a777021ce4f1a587070ebb548", null ],
      [ "Collinear_3", "classKernel.html#a766989eefac4e0617eb6ae7b66a20a2d", null ],
      [ "Collinear_are_ordered_along_line_2", "classKernel.html#aa436f3554628f3c391c8fb7e3bd5a1ee", null ],
      [ "Collinear_are_ordered_along_line_3", "classKernel.html#ad0784e9744533ad2c3c7849cc8e93f9e", null ],
      [ "Collinear_are_strictly_ordered_along_line_2", "classKernel.html#a30302745c6da8dc68730633806b20cd7", null ],
      [ "Collinear_are_strictly_ordered_along_line_3", "classKernel.html#a26736973d45b04d437748428da6649bb", null ],
      [ "Collinear_has_on_2", "classKernel.html#a584faff34bd03ac01c00b7fa52d90505", null ],
      [ "Compare_angle_3", "classKernel.html#aec03ca6c0bacc36397026a1deeb58de7", null ],
      [ "Compare_angle_with_x_axis_2", "classKernel.html#a83a486479218388c8e2075aff191109d", null ],
      [ "Compare_dihedral_angle_3", "classKernel.html#a00792fd1a5d950d54a750f4aa9d2ba3f", null ],
      [ "Compare_distance_2", "classKernel.html#accf923221d67f427a4e5a08c2d7120fb", null ],
      [ "Compare_distance_3", "classKernel.html#aa52b88a746b432ad721b2a3b767b525c", null ],
      [ "Compare_power_distance_2", "classKernel.html#af9f70ba9c2bb9ed7517ddc156a18e050", null ],
      [ "Compare_power_distance_3", "classKernel.html#aa3be6d5f6a0520be89167e273fb312f6", null ],
      [ "Compare_signed_distance_to_line_2", "classKernel.html#a066d07dd592ac36ba7ee90988abd349f", null ],
      [ "Compare_slope_2", "classKernel.html#aed1101d5f2a375e952d7276cac2d0cce", null ],
      [ "Compare_slope_3", "classKernel.html#a94bdcdbe4413e4f8bf36b4856cf5a466", null ],
      [ "Compare_square_distance_2", "classKernel.html#a925c8aa3251382d4865e0e98fa1e0642", null ],
      [ "Compare_squared_distance_3", "classKernel.html#a8cd4924e4f1874f1be370599ed2b3849", null ],
      [ "Compare_weighted_squared_radius_3", "classKernel.html#aed9f5dc1a2e49b0d8826edc8b294bbbe", null ],
      [ "Compare_x_2", "classKernel.html#aba51637d2c88f73c06cb67fb2f1b9b83", null ],
      [ "Compare_x_3", "classKernel.html#ad34fe10371a778e9f8b4b71c5455fd37", null ],
      [ "Compare_x_at_y_2", "classKernel.html#a8b7b3a01f6e3b90067479cd5735d628a", null ],
      [ "Compare_xy_2", "classKernel.html#ab2dc35d1a3971355babff4ceeaef7711", null ],
      [ "Compare_xy_3", "classKernel.html#a7462430add94d6811e87cdaa47de82de", null ],
      [ "Compare_xyz_3", "classKernel.html#afe5cb1dbaa03d83aab9d2b794743c581", null ],
      [ "Compare_y_2", "classKernel.html#a9f182cd61447e64005997e9d2a296700", null ],
      [ "Compare_y_3", "classKernel.html#a5f294bea9f2fc131aae86614cf7712e2", null ],
      [ "Compare_y_at_x_2", "classKernel.html#a25689f8b2c73c7468d6d620ebe93d299", null ],
      [ "Compare_yx_2", "classKernel.html#a7e50bcb8b9d7ca36463a3a458532ad6e", null ],
      [ "Compare_z_3", "classKernel.html#a185aadb6c13ee0e222b8538d67092130", null ],
      [ "Comparison_result", "classKernel.html#affdddb2220b43be2336136caf7162362", null ],
      [ "Compute_a_2", "classKernel.html#aee1804aac4384c43f700d44ef6181b6b", null ],
      [ "Compute_a_3", "classKernel.html#a7ffef8243002fee6e2316d5e6ab5988c", null ],
      [ "Compute_approximate_angle_3", "classKernel.html#a183c9ac358a4ccddc04e680f8ed16c0b", null ],
      [ "Compute_approximate_area_3", "classKernel.html#a79fb9aa5571d9334121daf3567b7de5e", null ],
      [ "Compute_approximate_dihedral_angle_3", "classKernel.html#a317517e99455eb94f76ecc870e8f007c", null ],
      [ "Compute_approximate_squared_length_3", "classKernel.html#a5442ec216c57261c3d09f8b3daae1b50", null ],
      [ "Compute_area_2", "classKernel.html#a65512a6256e52da1b41e904409ebefae", null ],
      [ "Compute_area_3", "classKernel.html#a6fb110e076db500661bff81fe3ccd530", null ],
      [ "Compute_area_divided_by_pi_3", "classKernel.html#a3ffcb6b6a2448eb20bd2cdef9b9b5f8f", null ],
      [ "Compute_b_2", "classKernel.html#ac6a96804410d59006880cb6fb1875656", null ],
      [ "Compute_b_3", "classKernel.html#a8ddb874ac12723bbb5da4a4dd011e992", null ],
      [ "Compute_c_3", "classKernel.html#a4c597bc0712e0f10d1b7bb5a2f2d7d90", null ],
      [ "Compute_d_3", "classKernel.html#a5156d692bfdf65b267827a5b603d601d", null ],
      [ "Compute_determinant_2", "classKernel.html#a5036665021dd09abb24a796a71d229dc", null ],
      [ "Compute_determinant_3", "classKernel.html#a53e17dfb8e20a54ad18eac8710272bd1", null ],
      [ "Compute_dx_2", "classKernel.html#a64bf0631705cba6033e91a7ca6577069", null ],
      [ "Compute_dx_3", "classKernel.html#a167a48183cf5ea5b0d545f3a5d580719", null ],
      [ "Compute_dy_2", "classKernel.html#afb24978def88a01f56d90288b16282fa", null ],
      [ "Compute_dy_3", "classKernel.html#ad9db5cc63ea4fa210ccd3442e3df10dd", null ],
      [ "Compute_dz_3", "classKernel.html#a0044e222f343f3469028a8a58f5f946a", null ],
      [ "Compute_hw_2", "classKernel.html#ae485fd1b0d84894ccff0a158d3451dc5", null ],
      [ "Compute_hw_3", "classKernel.html#a897d9fe962a7b9406065d55de2a41d89", null ],
      [ "Compute_hx_2", "classKernel.html#a7a40872675a3647a2eac74e9bf13d33f", null ],
      [ "Compute_hx_3", "classKernel.html#af814c13400bcc3db8454457513487d13", null ],
      [ "Compute_hy_2", "classKernel.html#a1729353651702c49e7b3df2b7fc70bda", null ],
      [ "Compute_hy_3", "classKernel.html#aecabaab5563e9176db8aa56a8c87aa64", null ],
      [ "Compute_hz_3", "classKernel.html#add4329831b7f0b4bfc92f23a6ce67d76", null ],
      [ "Compute_L_infinity_distance_2", "classKernel.html#a3d69e6fbec1efa3c9352b0c1c6f824e8", null ],
      [ "Compute_L_infinity_distance_3", "classKernel.html#aa4fdcaf1ff3ccab61b793ee09e4dbe2e", null ],
      [ "Compute_power_distance_to_power_sphere_3", "classKernel.html#ae1a2199acfc2620f107eaf7687d686d9", null ],
      [ "Compute_power_product_2", "classKernel.html#afcc480686ebfbe1a4e3dc9be647e84ef", null ],
      [ "Compute_power_product_3", "classKernel.html#a2b9d3909ee4e3c90f281f1ed10184f1e", null ],
      [ "Compute_scalar_product_2", "classKernel.html#a3361b8225f4d2be029925e2c88e1ca6c", null ],
      [ "Compute_scalar_product_3", "classKernel.html#a0c5fccb2b055f3cc7e4705bafabd6bc0", null ],
      [ "Compute_squared_area_3", "classKernel.html#a00f0daff8deaefae9f061884008cb76d", null ],
      [ "Compute_squared_distance_2", "classKernel.html#ab0cf8fb8b03a457251af5cd558f8e9b3", null ],
      [ "Compute_squared_distance_3", "classKernel.html#a0f2d1a3b455d293e04658d60ba4e9440", null ],
      [ "Compute_squared_length_2", "classKernel.html#abb2df449c5a20198be18dcc4a31d574a", null ],
      [ "Compute_squared_length_3", "classKernel.html#a92303f6ad57d9ee64472cdcdadef8178", null ],
      [ "Compute_squared_length_divided_by_pi_square_3", "classKernel.html#ade6801e06df10d3350584be6c324db83", null ],
      [ "Compute_squared_radius_2", "classKernel.html#a602bf0a1cf8bfc4253dbb88a64a0f8ab", null ],
      [ "Compute_squared_radius_3", "classKernel.html#ad9e31a8448baa677487ca63a3abf2b1a", null ],
      [ "Compute_squared_radius_smallest_orthogonal_circle_2", "classKernel.html#ac4e70985dc0d1100eeaf94f4b770a3ff", null ],
      [ "Compute_squared_radius_smallest_orthogonal_sphere_3", "classKernel.html#aab273473d7153f3e78cd8262e5883938", null ],
      [ "Compute_volume_3", "classKernel.html#a05b1aef299c88ca405d0826d946a5c95", null ],
      [ "Compute_weight_2", "classKernel.html#af702ee4cc54467afdac370d7174e9b63", null ],
      [ "Compute_weight_3", "classKernel.html#a7c9f6f66bd860a367320b04812dde454", null ],
      [ "Compute_x_2", "classKernel.html#a18fa41982f429df7181e1b9188688760", null ],
      [ "Compute_x_3", "classKernel.html#a04cc06ff6cc34a8566d2a5e2511c3715", null ],
      [ "Compute_xmax_2", "classKernel.html#a6435b09b36a8b59d28bf77ae43289af3", null ],
      [ "Compute_xmax_3", "classKernel.html#a5d77b1bc3c6f1c9774ea6b9153f3765c", null ],
      [ "Compute_xmin_2", "classKernel.html#a06f028addea0534295d4f013ddd06ab0", null ],
      [ "Compute_xmin_3", "classKernel.html#ae4c7986a74892db3576d598787f56f27", null ],
      [ "Compute_y_2", "classKernel.html#adc61bb4a938639db1b75dc970820fb1a", null ],
      [ "Compute_y_3", "classKernel.html#aa082637bc8550b35311d6189d554b457", null ],
      [ "Compute_y_at_x_2", "classKernel.html#a315676d30a652b2d80a0cfc1649f5576", null ],
      [ "Compute_ymax_2", "classKernel.html#a63ed13ed3181cb5b41f50c9e294bfe79", null ],
      [ "Compute_ymax_3", "classKernel.html#ad9b52222a8f49466d6b01a9960e2d4d1", null ],
      [ "Compute_ymin_2", "classKernel.html#a87a08a150d07c5be521fe3edea57f2a8", null ],
      [ "Compute_ymin_3", "classKernel.html#a7cf00bb42c610d70a949bcaeb0422743", null ],
      [ "Compute_z_3", "classKernel.html#a6167ac7adb272555561f384cc931cf4e", null ],
      [ "Compute_zmax_3", "classKernel.html#a0f9926566b5542171694d262eddeec1a", null ],
      [ "Compute_zmin_3", "classKernel.html#a7c8f1d10d5203382ef73ab9260f0c48c", null ],
      [ "ComputeC_2", "classKernel.html#aee7a2f36dedab76fab66f3c72bac53ed", null ],
      [ "Construct_barycenter_2", "classKernel.html#af05d28241249ddbf5a54de227b300f60", null ],
      [ "Construct_barycenter_3", "classKernel.html#a7123f2f2056f2060a7f9fef226407236", null ],
      [ "Construct_base_vector_3", "classKernel.html#a5eea92ff65c8cefd03e200353fc25f4e", null ],
      [ "Construct_bbox_2", "classKernel.html#a9e2c3a6f5add4668ef1001899189ff6b", null ],
      [ "Construct_bbox_3", "classKernel.html#afd675828adf8e71001863e02e7f8a9b7", null ],
      [ "Construct_bisector_2", "classKernel.html#a3f83360d66887fa7d0bd76145d4d7197", null ],
      [ "Construct_bisector_3", "classKernel.html#aeb82506928a0a46884f0ccdcaf18579b", null ],
      [ "Construct_cartesian_const_iterator_2", "classKernel.html#a19f74e5bc9526aa5eba5573995825152", null ],
      [ "Construct_cartesian_const_iterator_3", "classKernel.html#a4df83ad24f6e6a9b50ae1a49d70f965a", null ],
      [ "Construct_center_2", "classKernel.html#a0ce1636b18bba29e391938d8e28fafb7", null ],
      [ "Construct_center_3", "classKernel.html#a9d5085c77d1a83850a532ff6f395c002", null ],
      [ "Construct_centroid_2", "classKernel.html#a493f8b336c9b93dfec7d80453f37685c", null ],
      [ "Construct_centroid_3", "classKernel.html#af227a75dbadfa93dd9d151774747538b", null ],
      [ "Construct_circle_2", "classKernel.html#aba51c83dbb0385de251328f44c3061fd", null ],
      [ "Construct_circle_3", "classKernel.html#ae273aa7a89cd282a34f45c8663b1c9c2", null ],
      [ "Construct_circumcenter_2", "classKernel.html#a4f7da6f4e72ab3d8af4eb860621f4232", null ],
      [ "Construct_circumcenter_3", "classKernel.html#ac9292f7bcb85284d074ee10475e521e5", null ],
      [ "Construct_cross_product_vector_3", "classKernel.html#a24d80b97c895a2f5210d2db1e17eb68c", null ],
      [ "Construct_difference_of_vectors_2", "classKernel.html#a202621c2bf2294e39d0b9c8331d96808", null ],
      [ "Construct_difference_of_vectors_3", "classKernel.html#aae41cd83f6851f2f905000d689396d52", null ],
      [ "Construct_direction_2", "classKernel.html#a61c4ec98f4617144ca0ff9bb9dae45d2", null ],
      [ "Construct_direction_3", "classKernel.html#a5bd33a22e775e9ff59dd4954123f0c4e", null ],
      [ "Construct_divided_vector_2", "classKernel.html#ae1b57b13993e719416744d9f1196ebcd", null ],
      [ "Construct_divided_vector_3", "classKernel.html#ac1acaefa5802b4d5f0d55da2db09a8d0", null ],
      [ "Construct_equidistant_line_3", "classKernel.html#a96d4a35ac5ef01cb2895c07012328fff", null ],
      [ "Construct_iso_cuboid_3", "classKernel.html#ac197eb7a124afdbda6ccf7c5a30200f4", null ],
      [ "Construct_iso_rectangle_2", "classKernel.html#ae351546ad4ab38237d05d5fa345504dd", null ],
      [ "Construct_lifted_point_3", "classKernel.html#a1c5b2a8618fe6160898393f3940e9dcf", null ],
      [ "Construct_line_2", "classKernel.html#a2e4c57bf5aa81891903f30194fc93a34", null ],
      [ "Construct_line_3", "classKernel.html#a71a650dc875d527497edc5696851aae2", null ],
      [ "Construct_max_vertex_2", "classKernel.html#a0b1906541cdb614d815ab6e9b03f7da2", null ],
      [ "Construct_max_vertex_3", "classKernel.html#a95a3b964527265550344b53922dd7f48", null ],
      [ "Construct_midpoint_2", "classKernel.html#a95d601092f6432317789d3045f51b970", null ],
      [ "Construct_midpoint_3", "classKernel.html#aa47c38ed3c071e4e7f4fe9a3a41a4773", null ],
      [ "Construct_min_vertex_2", "classKernel.html#af356c83c2c62ab055fad3f67957971b4", null ],
      [ "Construct_min_vertex_3", "classKernel.html#a0670a2d81658def55308b0cae8e3710a", null ],
      [ "Construct_normal_3", "classKernel.html#af7169def413b62406c94eb89292fb013", null ],
      [ "Construct_object_2", "classKernel.html#a44e5872fc7266f0f1789130db091d0f1", null ],
      [ "Construct_object_3", "classKernel.html#a2cb3c746f2dec55826c168f73abaf711", null ],
      [ "Construct_opposite_circle_2", "classKernel.html#af0897d546f4952bf24e200a539dc44ab", null ],
      [ "Construct_opposite_direction_2", "classKernel.html#ae519d44a783ddf958db31e2e3292f624", null ],
      [ "Construct_opposite_direction_3", "classKernel.html#a222d3f6e3df674c6253e8610910a5065", null ],
      [ "Construct_opposite_line_2", "classKernel.html#a582130371dbdf93f8deac5d6f4bf3f21", null ],
      [ "Construct_opposite_line_3", "classKernel.html#a97d94d076be68c01585ea49750ed4b91", null ],
      [ "Construct_opposite_plane_3", "classKernel.html#ad551057086fb463e82fddb842b646979", null ],
      [ "Construct_opposite_ray_2", "classKernel.html#a92cbcdabf0e55d707fb64a0a739d4632", null ],
      [ "Construct_opposite_ray_3", "classKernel.html#a27bc2d6a43a57d90209488c52589a4b0", null ],
      [ "Construct_opposite_segment_2", "classKernel.html#af962e3e4ba3d2f6226a57b03e9de7363", null ],
      [ "Construct_opposite_segment_3", "classKernel.html#adf0d93f7d558f60fc05b824e9e70391e", null ],
      [ "Construct_opposite_sphere_3", "classKernel.html#a851e2324c311040d1144eb2d54b3ece9", null ],
      [ "Construct_opposite_triangle_2", "classKernel.html#a74bf1fc7824b007ad9fb8e473fcab4a0", null ],
      [ "Construct_opposite_vector_2", "classKernel.html#abf6974d9faf4e1201a2805a1871b4afa", null ],
      [ "Construct_opposite_vector_3", "classKernel.html#a655ec53e204c68fdd21b2efc71605317", null ],
      [ "Construct_orthogonal_vector_3", "classKernel.html#a0f51a8359793afd986e2b392d9d34ee3", null ],
      [ "Construct_perpendicular_direction_2", "classKernel.html#a57d4915f52effcac6f7a7758cfbf4f9d", null ],
      [ "Construct_perpendicular_line_2", "classKernel.html#a779754c3614db506e78d89500519116f", null ],
      [ "Construct_perpendicular_line_3", "classKernel.html#a5cb169e2b442a512de11d7869b15ee50", null ],
      [ "Construct_perpendicular_plane_3", "classKernel.html#a6a5564301866fa70ca9240247acd07d3", null ],
      [ "Construct_perpendicular_vector_2", "classKernel.html#ac24ba129406475efcda3ad299c62c539", null ],
      [ "Construct_plane_3", "classKernel.html#a2cf2bb52d8181afb246d4f688d61e6a2", null ],
      [ "Construct_point_2", "classKernel.html#a5a6bde6968b2bed5ab305d9678d937eb", null ],
      [ "Construct_point_3", "classKernel.html#a37e4ae60cf3e2e62182652c099ff7242", null ],
      [ "Construct_point_on_2", "classKernel.html#a20a6c8dd11686f463b1fef21015550d6", null ],
      [ "Construct_point_on_3", "classKernel.html#a58981f482813bd5a7b09298e0fa4f010", null ],
      [ "Construct_projected_point_2", "classKernel.html#aa87bc881463585a3c2e59fbd5983b0a4", null ],
      [ "Construct_projected_point_3", "classKernel.html#a01cc5f4d4d1cf8942b6ffa8bc579c2ff", null ],
      [ "Construct_projected_xy_point_2", "classKernel.html#abfd9d4d7f0d8d0d60284a874fdc7def5", null ],
      [ "Construct_radical_axis_2", "classKernel.html#ac89f11b706796fd8a3be942c6bd27ac7", null ],
      [ "Construct_radical_line_2", "classKernel.html#a7e3400e0325bb71fd4add4f09074a7eb", null ],
      [ "Construct_radical_plane_3", "classKernel.html#a82dd4f473430241c981fada403fd1aa0", null ],
      [ "Construct_ray_2", "classKernel.html#a7e44b0be4478d2dc554b92d2c10b633e", null ],
      [ "Construct_ray_3", "classKernel.html#a2e3239b866e2726dabd4bb638d6caf9f", null ],
      [ "Construct_scaled_vector_2", "classKernel.html#aa8af7b0762db570b28a6d41463f30684", null ],
      [ "Construct_scaled_vector_3", "classKernel.html#ae66d90bc035e020c1dee156cbc3495b9", null ],
      [ "Construct_second_point_2", "classKernel.html#a3fdb153d9b844e8e7b4d6f37f3f51c9b", null ],
      [ "Construct_second_point_3", "classKernel.html#af618586c66588d8f34275975f3a6c87b", null ],
      [ "Construct_segment_2", "classKernel.html#a003dc3b31e98f1589334d9e9c6c6cc73", null ],
      [ "Construct_segment_3", "classKernel.html#a470f084837d4a3d50f6d80546d68454d", null ],
      [ "Construct_source_2", "classKernel.html#ae903d886fdfcb04f1f8444789471dd1b", null ],
      [ "Construct_source_3", "classKernel.html#a9ecb7779a2efe355d04e564c58a285ac", null ],
      [ "Construct_sphere_3", "classKernel.html#aa0b2041132d0a233d751fe71698c069f", null ],
      [ "Construct_sum_of_vectors_2", "classKernel.html#a5c40580acc620a8d124c193d58c44d15", null ],
      [ "Construct_sum_of_vectors_3", "classKernel.html#aed46266061a47cb78b801b3212f88ae4", null ],
      [ "Construct_supporting_plane_3", "classKernel.html#aeb7346228822b4d4ff26a83419379697", null ],
      [ "Construct_target_2", "classKernel.html#ae3f8b3ef2cb6939706553ff7c7f600a0", null ],
      [ "Construct_target_3", "classKernel.html#ae98b1fee8e0173a8f24be456e849b04f", null ],
      [ "Construct_tetrahedron_3", "classKernel.html#a5b040f3ac934277e5a4dd09d4fd06418", null ],
      [ "Construct_translated_point_2", "classKernel.html#a3e497e507c04ec9c786dea6b3f75504f", null ],
      [ "Construct_translated_point_3", "classKernel.html#a185cefec2e47f5a993bdc5be0155332f", null ],
      [ "Construct_triangle_2", "classKernel.html#a98e7a2a4d420deba1d31046c65d0d187", null ],
      [ "Construct_triangle_3", "classKernel.html#aeb96d54a57066a46414bddc2dba24ce5", null ],
      [ "Construct_vector_2", "classKernel.html#ab12e046a450569c7a72ee74f4f1c77c8", null ],
      [ "Construct_vector_3", "classKernel.html#abf20ed4375d501fdf4d0e139838ca0dc", null ],
      [ "Construct_vertex_2", "classKernel.html#a329daefa3f2da19469ea43b361383c4c", null ],
      [ "Construct_vertex_3", "classKernel.html#aa3bf5484870888b01da04171342044c8", null ],
      [ "Construct_weighted_circumcenter_2", "classKernel.html#ad18756bc07d12b54d5f32bb2836caab0", null ],
      [ "Construct_weighted_circumcenter_3", "classKernel.html#af0e404471d294d0837e0fda779340a9d", null ],
      [ "Construct_weighted_point_2", "classKernel.html#a8d2cfcf72a29f12ec3956b6be94cd57f", null ],
      [ "Construct_weighted_point_3", "classKernel.html#a90bed2248d27faeedb1631cec962ce90", null ],
      [ "Coplanar_3", "classKernel.html#acdca7cf97d1472b205e79bafb9af5882", null ],
      [ "Coplanar_orientation_3", "classKernel.html#a1b3802a924567ea4e5439e081bee571c", null ],
      [ "Coplanar_side_of_bounded_circle_3", "classKernel.html#a1296960ac11754501db6633b29d8b0b6", null ],
      [ "Counterclockwise_in_between_2", "classKernel.html#af75350d5060e149b5acd798ab3f1072b", null ],
      [ "Direction_2", "classKernel.html#a3b47b69a084db52a1b94492cc76fe6c6", null ],
      [ "Direction_3", "classKernel.html#a1fe229171fb316bd3c2cb6b7fff0caa4", null ],
      [ "Do_intersect_2", "classKernel.html#a66956c9eb7a1e2042326b051ecef8020", null ],
      [ "Do_intersect_3", "classKernel.html#adf4b45486ddac1219aa419fc62c38e1b", null ],
      [ "Equal_2", "classKernel.html#a33877b518d8a2035a0391de8bbdfb3d9", null ],
      [ "Equal_3", "classKernel.html#a4dedd09115e35bd834ef806fe1a3efff", null ],
      [ "Equal_x_2", "classKernel.html#a8a51c41f4e3fcd24eb3765a54959ff42", null ],
      [ "Equal_x_3", "classKernel.html#ab44571b14eed530b19dd17fd7f8f3912", null ],
      [ "Equal_xy_3", "classKernel.html#a05a05e6139558f2cd6e228d7411796ea", null ],
      [ "Equal_y_2", "classKernel.html#a455b024b7dbc76be321ba756308f8ff7", null ],
      [ "Equal_y_3", "classKernel.html#a5f7c32b31300d910d34d28aabcf439a9", null ],
      [ "Equal_z_3", "classKernel.html#a77a5b84e56a7c58a89957b1d358a3a45", null ],
      [ "FT", "classKernel.html#a55e83f5a9f8ca43588b02ae8256a8fbd", null ],
      [ "Has_on_2", "classKernel.html#aabcfa7dbff50f18e39dffcd697a137fb", null ],
      [ "Has_on_3", "classKernel.html#a2fd5b338f8730990dcdf0234c6c7d6c2", null ],
      [ "Has_on_boundary_2", "classKernel.html#a88a204170c7aa42cca7337743530c93b", null ],
      [ "Has_on_boundary_3", "classKernel.html#a670e64f1f02972b431acaa512e9b4ddb", null ],
      [ "Has_on_bounded_side_2", "classKernel.html#a8a0e8f75024f795eec06910ea141ff38", null ],
      [ "Has_on_bounded_side_3", "classKernel.html#abec7fc4c1bf5a7ce8d0a8a3a41a1b99a", null ],
      [ "Has_on_negative_side_2", "classKernel.html#a0c24f61400d6431aa74a159d5f2da133", null ],
      [ "Has_on_negative_side_3", "classKernel.html#a7310d7721dbcf201358eda3e4d632c2d", null ],
      [ "Has_on_positive_side_2", "classKernel.html#a6d3d15a521c10e8b997ebdfb7e2e101c", null ],
      [ "Has_on_positive_side_3", "classKernel.html#a542b9a3d22f86e0d8c199304f2b739ef", null ],
      [ "Has_on_unbounded_side_2", "classKernel.html#ab041aafd45ce93630bfe77cec24e24f3", null ],
      [ "Has_on_unbounded_side_3", "classKernel.html#ada27f27602757133ea7b9814ada00ba3", null ],
      [ "Intersect_2", "classKernel.html#a24201ae9d085899730262c570090bae0", null ],
      [ "Intersect_3", "classKernel.html#a3eb05ddfe6fc3a39eaa4d2ff5486c61e", null ],
      [ "Is_degenerate_2", "classKernel.html#a08eecca020c623d68451615fbc0dc335", null ],
      [ "Is_degenerate_3", "classKernel.html#a3e9cbf5d7ced1307899138263748be7c", null ],
      [ "Is_horizontal_2", "classKernel.html#a650ee93a804715b0c0cc564703809f80", null ],
      [ "Is_vertical_2", "classKernel.html#a24cecc377691dbcd9b1232595e4e5f97", null ],
      [ "Iso_cuboid_3", "classKernel.html#af4995844c84fe8c84df2db6660682c4e", null ],
      [ "Iso_rectangle_2", "classKernel.html#a8cb91579c64d06d9a2c67d72cd1fafec", null ],
      [ "Left_turn_2", "classKernel.html#acd069e934f26d01bbe9a7ea26ae7c1d0", null ],
      [ "Less_distance_to_point_2", "classKernel.html#ae05d13af9dc0ffa7c7475e23596c12bf", null ],
      [ "Less_distance_to_point_3", "classKernel.html#aa25b8d1f048637a1e301c69f79dd7e3e", null ],
      [ "Less_rotate_ccw_2", "classKernel.html#acb8b8e2156dbdb827020b4d44be7f8b2", null ],
      [ "Less_signed_distance_to_line_2", "classKernel.html#ae9102c471c69d082a8716fb70a0050f4", null ],
      [ "Less_signed_distance_to_plane_3", "classKernel.html#aee154c217888bc20b499156303929436", null ],
      [ "Less_x_2", "classKernel.html#a2f148e743c5f3c3e6baa550f3e52c87e", null ],
      [ "Less_x_3", "classKernel.html#a923d57d9714dd33ef6714383fd36f8de", null ],
      [ "Less_xy_2", "classKernel.html#a553d3ffe254027750cb78d4d7a617538", null ],
      [ "Less_xy_3", "classKernel.html#ade6410aa243f34b598da6c2306e84f0f", null ],
      [ "Less_xyz_3", "classKernel.html#a628aca558e49cd100d5305c0afc7703e", null ],
      [ "Less_y_2", "classKernel.html#a73d02990587c6e0c20c85ce7b50289b2", null ],
      [ "Less_y_3", "classKernel.html#af0bd76a2213ecd3cf2a5b73a88d86a09", null ],
      [ "Less_yx_2", "classKernel.html#a66b972f509d488302bcd02d882565ba0", null ],
      [ "Less_z_3", "classKernel.html#a6cfffe8c47d7de186e05e42c60c3a41c", null ],
      [ "Line_2", "classKernel.html#add6b18567776ee7e80dfdfa44c304772", null ],
      [ "Line_3", "classKernel.html#a6601ab0cd26186d77d45dd745bb41f14", null ],
      [ "Non_zero_coordinate_index_3", "classKernel.html#a25a8b7e04b0d0acadd580c61d11892ac", null ],
      [ "Object_2", "classKernel.html#a574944649ac83254e8a6de8e96dc34c1", null ],
      [ "Object_3", "classKernel.html#a74a1683f7c00e33ee9e439e52fe61594", null ],
      [ "Orientation", "classKernel.html#ac3987564bd4891820ba667615d59090b", null ],
      [ "Orientation_2", "classKernel.html#a611edc06aa99abc92b65cff1785e222a", null ],
      [ "Orientation_3", "classKernel.html#a9b294b51e660da2af68910ac47803b0f", null ],
      [ "Oriented_side", "classKernel.html#a5f8e7f184d051becb9d1e38d904d9030", null ],
      [ "Oriented_side_2", "classKernel.html#a846946d2a18ecbb4215a8c7620af4eef", null ],
      [ "Oriented_side_3", "classKernel.html#a221f836d9c88f71966dba003e68f1fad", null ],
      [ "Plane_3", "classKernel.html#ac027cb2dbfb711e19826dc83b957033f", null ],
      [ "Point_2", "classKernel.html#ada7ccf9efead4df158c2317406e5fa6c", null ],
      [ "Point_3", "classKernel.html#ae82b7f4be77dd5b8819ebe419e4ae753", null ],
      [ "Power_side_of_bounded_power_circle_2", "classKernel.html#a8cac54c97cc045f0d1589682b16c11fd", null ],
      [ "Power_side_of_bounded_power_sphere_3", "classKernel.html#a2fcc63a29a0b725cf8b18f49e0b03576", null ],
      [ "Power_side_of_oriented_power_circle_2", "classKernel.html#a082edac6f33fbeec587619a73ae5beac", null ],
      [ "Power_side_of_oriented_power_sphere_3", "classKernel.html#abe44412d444ec473f96e10dd312b77ba", null ],
      [ "Ray_2", "classKernel.html#adf1e3e3880a35c429c57c79d649e9a5e", null ],
      [ "Ray_3", "classKernel.html#a93cd09369856a7f4b8b19b94b6554027", null ],
      [ "RT", "classKernel.html#aacd6ff704fc864440c40993a40210f6b", null ],
      [ "Segment_2", "classKernel.html#aa6d2526f8d1571f4a38aa8a6d9a02c2b", null ],
      [ "Segment_3", "classKernel.html#aa43a461b2027ef7d99b776a7b03ef230", null ],
      [ "Side_of_bounded_circle_2", "classKernel.html#ac0e5df8284007be5a43d29f2c3e98b8e", null ],
      [ "Side_of_bounded_sphere_3", "classKernel.html#a01761cfb697ca227efe32a85643c6ae0", null ],
      [ "Side_of_oriented_circle_2", "classKernel.html#a1416a082680b19fb075a71661c5fe2a9", null ],
      [ "Side_of_oriented_sphere_3", "classKernel.html#a841f155da66265dd2e8c7399e16c61e5", null ],
      [ "Sign", "classKernel.html#a67055794ead3a9ecd8e8284e1f92eafc", null ],
      [ "Sphere_3", "classKernel.html#a601207c3e7157f868a2e473791bf38c5", null ],
      [ "Tetrahedron_3", "classKernel.html#aad6b946fde186c084cd49dd7684aefe1", null ],
      [ "Triangle_2", "classKernel.html#aeb5fdd2b0e4b5f97f37815ea28d5c7a9", null ],
      [ "Triangle_3", "classKernel.html#abb5c0e1064f61672b5a4b95d39ba1583", null ],
      [ "Vector_2", "classKernel.html#ac99a26c147a66317cc6afcaf27b091e2", null ],
      [ "Vector_3", "classKernel.html#a39fb0222695ae5e7e32f4e570ea28225", null ],
      [ "Weighted_point_2", "classKernel.html#a0840945f50320f998ee74f212ecaf082", null ],
      [ "Weighted_point_3", "classKernel.html#a9048cf2dfda25db2f1bcd7f66b5585b1", null ],
      [ "construct_vector_2_object", "classKernel.html#a82111132db3c8afe8e4a87ce5cb87b9e", null ],
      [ "Has_filtered_predicates", "classKernel.html#aa0116f436c29a44078471dcf595a37d6", null ]
    ] ],
    [ "ProjectionTraitsGeometricTraits_3", "classProjectionTraitsGeometricTraits__3.html", null ]
];